"""Autogenerated API"""
from argus_api.session import _legacy_session as session
import logging
from argus_cli.plugin import register_command
from argus_plugins import argus_cli_module
from argus_api.utils import deprecated_alias
log = logging.getLogger(__name__)


@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def authorize(
    responseType: str = None,
    clientID: str = None,
    redirectURI: str = None,
    state: str = None,
    nonce: str = None,
    scope: str = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Request authorization to a OAuth client (INTERNAL)
    
    :param list responseType: Type of response requested.
    :param str clientID: The clientID of the requesting client.
    :param str redirectURI: The redirectURI requested by the client.
    :param str state: The state submitted by the client. This state should follow unmodified back to the redirect response after a valid client authorization.
    :param str nonce: A nonce requested by the client. The nonce should pass through unmodified and follow the token issued for this request.
    :param list scope: The scopes requested by the client. If \'openid\' is in scope\, this is an OpenID request.
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/authorize".format()
    headers = {}

    body = body or {}
    # Only send responseType if the argument was provided, don't send null values
    if responseType is not None:
        body.update({"responseType": responseType})
    # Only send clientID if the argument was provided, don't send null values
    if clientID is not None:
        body.update({"clientID": clientID})
    # Only send redirectURI if the argument was provided, don't send null values
    if redirectURI is not None:
        body.update({"redirectURI": redirectURI})
    # Only send state if the argument was provided, don't send null values
    if state is not None:
        body.update({"state": state})
    # Only send nonce if the argument was provided, don't send null values
    if nonce is not None:
        body.update({"nonce": nonce})
    # Only send scope if the argument was provided, don't send null values
    if scope is not None:
        body.update({"scope": scope})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def create_oauth2_client(
    shortName: str = None,
    name: str = None,
    description: str = None,
    domain: str = None,
    customer: str = None,
    mainURI: str = None,
    redirectURIs: str = None,
    requiredFunction: str = None,
    permissionScope: str = None,
    authenticationMethod: str = None,
    clientSecret: str = None,
    clientIPRange: str = None,
    openIDCustomClaims: dict = None,
    maxSecurityLevel: str = None,
    hidden: bool = None,
    redirectURI: str = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Define a new OAuth2 client (PUBLIC)
    
    :param str shortName: A shortname describing this resource. This name will show up when listing external resources. \=\> \[a\-zA\-Z0\-9\_\:\\\-\\.\]\*
    :param str name: A name describing this resource. This name will show up when listing external resources. \=\> \[\\s\\w\\\{\\\}\\\$\\\-\\\(\\\)\\.\\\[\\\]\"\\\'\_\/\\\\\,\\\*\\\+\\\#\:\@\!\?\;\=\]\*
    :param str description: A description of this resource. \=\> \[\\s\\w\\\{\\\}\\\$\\\-\\\(\\\)\\.\\\[\\\]\"\\\'\_\/\\\\\,\\\*\\\+\\\#\:\@\!\?\;\=\]\*
    :param str domain: Specifies the domain in which this resource is defined. The user must have the required function for this domain. If customer is set\, the customer must be defined in this domain. If this field is not set\, it defaults to the current users domain.
    :param str customer: Specifying a customer will restrict this resource to a specific customer. This will limit access to this resource to users having the required function for this specific customer. The resource clients delegated session will also be constrained to this particular customer. If customer is not specified\, access to this resource will be given to users having the requiredFunction for any customer.
    :param str mainURI: The main landing page for this resource. This will be used to link to the application from Argus. \=\> Sanitize by regex https\:\/\/.\*
    :param list redirectURIs: The redirect URIs to allow when redirecting from the OAuth authorization endpoint. \=\> Sanitize by regex http\(s\)\?\:\/\/.\*
    :param str requiredFunction: The function \(id or name\) required to grant access to this resource. If customer is specified\, this function is required for that particular customer.
    :param str permissionScope: The function\/role \(id or name\) to constrain the delegated client session to\, restricting what the resource client will be allowed to do on behalf of the user. The delegated client session will be constrained to the least set of the users current session permissions\, and this role.
    :param str authenticationMethod: The authentication method required for this client. Default is password.
    :param str clientSecret: If authenticationMethod is password\, the password must be provided in the clientSecret parameter.
    :param list clientIPRange: A list of CIDR IP ranges which the client will be permitted from. \=\> format\:ip
    :param list openIDCustomClaims: Optional custom claims configuration. See documentation for valid configuration format per custom claim.
    :param str maxSecurityLevel: Max security level for this client \(default external\)
    :param bool hidden: If true\, this client is by default excluded in the oauth external client list
    :param str redirectURI: DEPRECATED\: This field is DEPRECATED. Use redirectURIs instead.
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/client".format()
    headers = {}

    body = body or {}
    # Only send shortName if the argument was provided, don't send null values
    if shortName is not None:
        body.update({"shortName": shortName})
    # Only send name if the argument was provided, don't send null values
    if name is not None:
        body.update({"name": name})
    # Only send description if the argument was provided, don't send null values
    if description is not None:
        body.update({"description": description})
    # Only send domain if the argument was provided, don't send null values
    if domain is not None:
        body.update({"domain": domain})
    # Only send customer if the argument was provided, don't send null values
    if customer is not None:
        body.update({"customer": customer})
    # Only send mainURI if the argument was provided, don't send null values
    if mainURI is not None:
        body.update({"mainURI": mainURI})
    # Only send redirectURIs if the argument was provided, don't send null values
    if redirectURIs is not None:
        body.update({"redirectURIs": redirectURIs})
    # Only send requiredFunction if the argument was provided, don't send null values
    if requiredFunction is not None:
        body.update({"requiredFunction": requiredFunction})
    # Only send permissionScope if the argument was provided, don't send null values
    if permissionScope is not None:
        body.update({"permissionScope": permissionScope})
    # Only send authenticationMethod if the argument was provided, don't send null values
    if authenticationMethod is not None:
        body.update({"authenticationMethod": authenticationMethod})
    # Only send clientSecret if the argument was provided, don't send null values
    if clientSecret is not None:
        body.update({"clientSecret": clientSecret})
    # Only send clientIPRange if the argument was provided, don't send null values
    if clientIPRange is not None:
        body.update({"clientIPRange": clientIPRange})
    # Only send openIDCustomClaims if the argument was provided, don't send null values
    if openIDCustomClaims is not None:
        body.update({"openIDCustomClaims": openIDCustomClaims})
    # Only send maxSecurityLevel if the argument was provided, don't send null values
    if maxSecurityLevel is not None:
        body.update({"maxSecurityLevel": maxSecurityLevel})
    # Only send hidden if the argument was provided, don't send null values
    if hidden is not None:
        body.update({"hidden": hidden})
    # Only send redirectURI if the argument was provided, don't send null values
    if redirectURI is not None:
        body.update({"redirectURI": redirectURI})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def delete_oauth2_client(
    idOrShortname: str,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Delete a OAuth2 client (PUBLIC)
    
    :param str idOrShortname: ID or shortname of client to delete
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises SpecifiedObjectWasNotFoundException: on 404
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/client/{idOrShortname}".format(idOrShortname=idOrShortname)
    headers = {}

    body = body or {}

    query_parameters = {}
    log.debug("DELETE %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.delete(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def get_oauth2_client(
    idOrShortname: str,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Fetch a OAuth2 client descriptor (PUBLIC)
    
    :param str idOrShortname: ID or shortname of client to fetch
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises SpecifiedObjectWasNotFoundException: on 404
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/client/{idOrShortname}".format(idOrShortname=idOrShortname)
    headers = {}

    body = body or {}

    query_parameters = {}
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def get_token(
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Exchange a OAuth2 authorization code with an access token (PUBLIC)
    
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises ValidationErrorException: on 400
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/token".format()
    headers = {}

    body = body or {}

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        data=body or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def get_user_info(
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Return OpenID userinfo (PUBLIC)
    
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/userinfo".format()
    headers = {}

    body = body or {}

    query_parameters = {}
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def list_oauth2_clients(
    customer: str = None,
    domain: str = None,
    keywords: str = None,
    sortBy: str = None,
    limit: int = 25,
    offset: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """List available OAuth2 client descriptors (PUBLIC)
    
    :param list customer: Limit results to clients for this customer \(or subcustomers\)
    :param list domain: Limit results to clients for this domain
    :param list keywords: Limit results to clients matching these keywords
    :param list sortBy: Specify sort order
    :param int limit: Limit number of results
    :param int offset: Skip a number of results
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises SpecifiedObjectWasNotFoundException: on 404
    :raises InvalidArgumentException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/client".format(limit=limit,
        customer=customer,
        domain=domain,
        keywords=keywords,
        sortBy=sortBy,
        offset=offset)
    headers = {}

    body = body or {}

    query_parameters = {}
    # Only send limit if the argument was provided, don't send null values
    if limit is not None:
        query_parameters.update({"limit": limit})
    
    # Only send customer if the argument was provided, don't send null values
    if customer is not None:
        query_parameters.update({"customer": customer})
    
    # Only send domain if the argument was provided, don't send null values
    if domain is not None:
        query_parameters.update({"domain": domain})
    
    # Only send keywords if the argument was provided, don't send null values
    if keywords is not None:
        query_parameters.update({"keywords": keywords})
    
    # Only send sortBy if the argument was provided, don't send null values
    if sortBy is not None:
        query_parameters.update({"sortBy": sortBy})
    
    # Only send offset if the argument was provided, don't send null values
    if offset is not None:
        query_parameters.update({"offset": offset})
    
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def post_user_info(
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Return OpenID userinfo (PUBLIC)
    
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/userinfo".format()
    headers = {}

    body = body or {}

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def search_oauth2_clients(
    includeFlags: str = None,
    customer: str = None,
    domain: str = None,
    requiredFunction: str = None,
    subCriteria: dict = None,
    keywords: str = None,
    keywordMatchStrategy: str = None,
    keywordFieldStrategy: str = None,
    excludeFlags: str = None,
    sortBy: str = None,
    limit: int = 25,
    offset: int = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Search available OAuth2 client descriptors (PUBLIC)
    
    :param list includeFlags: Include clients having all these flags
    :param list customer: Match clients bound to any of these customers \(by id or shortname\)
    :param list domain: Match clients bound to any of these domains \(by id or shortname\)
    :param list requiredFunction: Match clients having any of the specified functions \(id or shortname\) as requiredFunction
    :param list subCriteria: Subcriteria for this search request
    :param list keywords: Match clients by these keywords
    :param str keywordMatchStrategy: Search based on all keywords \(AND\)\, or based on any keyword \(OR\) \(default Match all keywords \(AND\)\)
    :param list keywordFieldStrategy: Which fields will be searched for the given keyword \(default All supported fields\)
    :param list excludeFlags: Exclude clients having any of these flags
    :param list sortBy: Specify sort order \(default shortName\)
    :param int limit: Limit the number of results \(default 25\)
    :param int offset: Skip the first results\, in sort order \(default 0\)
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises SpecifiedObjectWasNotFoundException: on 404
    :raises InvalidArgumentException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/client/search".format()
    headers = {}

    body = body or {}
    # Only send includeFlags if the argument was provided, don't send null values
    if includeFlags is not None:
        body.update({"includeFlags": includeFlags})
    # Only send customer if the argument was provided, don't send null values
    if customer is not None:
        body.update({"customer": customer})
    # Only send domain if the argument was provided, don't send null values
    if domain is not None:
        body.update({"domain": domain})
    # Only send requiredFunction if the argument was provided, don't send null values
    if requiredFunction is not None:
        body.update({"requiredFunction": requiredFunction})
    # Only send subCriteria if the argument was provided, don't send null values
    if subCriteria is not None:
        body.update({"subCriteria": subCriteria})
    # Only send keywords if the argument was provided, don't send null values
    if keywords is not None:
        body.update({"keywords": keywords})
    # Only send keywordMatchStrategy if the argument was provided, don't send null values
    if keywordMatchStrategy is not None:
        body.update({"keywordMatchStrategy": keywordMatchStrategy})
    # Only send keywordFieldStrategy if the argument was provided, don't send null values
    if keywordFieldStrategy is not None:
        body.update({"keywordFieldStrategy": keywordFieldStrategy})
    # Only send excludeFlags if the argument was provided, don't send null values
    if excludeFlags is not None:
        body.update({"excludeFlags": excludeFlags})
    # Only send limit if the argument was provided, don't send null values
    if limit is not None:
        body.update({"limit": limit})
    # Only send offset if the argument was provided, don't send null values
    if offset is not None:
        body.update({"offset": offset})
    # Only send sortBy if the argument was provided, don't send null values
    if sortBy is not None:
        body.update({"sortBy": sortBy})

    query_parameters = {}
    log.debug("POST %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

@register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module
)
def update_oauth2_client(
    idOrShortname: str,
    shortName: str = None,
    name: str = None,
    description: str = None,
    mainURI: str = None,
    redirectURIs: str = None,
    requiredFunction: str = None,
    permissionScope: str = None,
    authenticationMethod: str = None,
    clientSecret: str = None,
    clientIPRange: str = None,
    openIDCustomClaims: dict = None,
    maxSecurityLevel: str = None,
    hidden: bool = None,
    redirectURI: str = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Update an existing OAuth2 client (PUBLIC)
    
    :param str idOrShortname: ID or shortname of OAuth2 client to update
    :param str shortName: If set\, update the shortname describing this resource. This name will show up when listing external resources. \=\> \[a\-zA\-Z0\-9\_\:\\\-\\.\]\*
    :param str name: If set\, update the name describing this resource. This name will show up when listing external resources. \=\> \[\\s\\w\\\{\\\}\\\$\\\-\\\(\\\)\\.\\\[\\\]\"\\\'\_\/\\\\\,\\\*\\\+\\\#\:\@\!\?\;\=\]\*
    :param str description: If set\, update the description of this resource. \=\> \[\\s\\w\\\{\\\}\\\$\\\-\\\(\\\)\\.\\\[\\\]\"\\\'\_\/\\\\\,\\\*\\\+\\\#\:\@\!\?\;\=\]\*
    :param str mainURI: If set\, update the main landing page for this resource. This will be used to link to the application from Argus. \=\> Sanitize by regex https\:\/\/.\*
    :param list redirectURIs: If set\, update the redirect URIs to allow when redirecting from the OAuth authorization endpoint. \=\> Sanitize by regex http\(s\)\?\:\/\/.\*
    :param str requiredFunction: If set\, change the function \(id or name\) required to grant access to this resource. If customer is specified\, this function is required for that particular customer.
    :param str permissionScope: If set\, change the function\/role \(id or name\) to constrain the delegated client session to\, restricting what the resource client will be allowed to do on behalf of the user. The delegated client session will be constrained to the least set of the users current session permissions\, and this role.
    :param str authenticationMethod: If set\, change the authentication method required for this client.
    :param str clientSecret: If set\, update the client secret of this OAuth2 client. If changing authenticationMethod to password\, the password must be provided in this clientSecret parameter.
    :param list clientIPRange: If set\, change the CIDR IP ranges which the client will be permitted from. \=\> format\:ip
    :param list openIDCustomClaims: If set\, overwrite any existing custom claims configuration. This would remove any existing providers. Use empty array to remove all existing providers.
    :param str maxSecurityLevel: If set\, change the max security level for this client
    :param bool hidden: If set\, change the value of the \'hidden\' flag on this client. A hidden client is by default excluded from the oauth client application list.
    :param str redirectURI: DEPRECATED\: This field is DEPRECATED. Use redirectURIs instead.
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/authentication/v1/oauth/client/{idOrShortname}".format(idOrShortname=idOrShortname)
    headers = {}

    body = body or {}
    # Only send shortName if the argument was provided, don't send null values
    if shortName is not None:
        body.update({"shortName": shortName})
    # Only send name if the argument was provided, don't send null values
    if name is not None:
        body.update({"name": name})
    # Only send description if the argument was provided, don't send null values
    if description is not None:
        body.update({"description": description})
    # Only send mainURI if the argument was provided, don't send null values
    if mainURI is not None:
        body.update({"mainURI": mainURI})
    # Only send redirectURIs if the argument was provided, don't send null values
    if redirectURIs is not None:
        body.update({"redirectURIs": redirectURIs})
    # Only send requiredFunction if the argument was provided, don't send null values
    if requiredFunction is not None:
        body.update({"requiredFunction": requiredFunction})
    # Only send permissionScope if the argument was provided, don't send null values
    if permissionScope is not None:
        body.update({"permissionScope": permissionScope})
    # Only send authenticationMethod if the argument was provided, don't send null values
    if authenticationMethod is not None:
        body.update({"authenticationMethod": authenticationMethod})
    # Only send clientSecret if the argument was provided, don't send null values
    if clientSecret is not None:
        body.update({"clientSecret": clientSecret})
    # Only send clientIPRange if the argument was provided, don't send null values
    if clientIPRange is not None:
        body.update({"clientIPRange": clientIPRange})
    # Only send openIDCustomClaims if the argument was provided, don't send null values
    if openIDCustomClaims is not None:
        body.update({"openIDCustomClaims": openIDCustomClaims})
    # Only send maxSecurityLevel if the argument was provided, don't send null values
    if maxSecurityLevel is not None:
        body.update({"maxSecurityLevel": maxSecurityLevel})
    # Only send hidden if the argument was provided, don't send null values
    if hidden is not None:
        body.update({"hidden": hidden})
    # Only send redirectURI if the argument was provided, don't send null values
    if redirectURI is not None:
        body.update({"redirectURI": redirectURI})

    query_parameters = {}
    log.debug("PUT %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.put(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

#: **DEPRECATED** : ``create_o_auth2_client`` is an alias for ``create_oauth2_client``. Exists
#: only for backward compatibility - **do not use** - use ``create_oauth2_client`` instead.
create_o_auth2_client = register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module,
    alias="create_o_auth2_client"
)(deprecated_alias("create_o_auth2_client")(create_oauth2_client))
#: **DEPRECATED** : ``update_o_auth2_client`` is an alias for ``update_oauth2_client``. Exists
#: only for backward compatibility - **do not use** - use ``update_oauth2_client`` instead.
update_o_auth2_client = register_command(
    extending=("authentication", "v1", "oauth", "authorize"),
    module=argus_cli_module,
    alias="update_o_auth2_client"
)(deprecated_alias("update_o_auth2_client")(update_oauth2_client))