"""Autogenerated API"""
from argus_api.session import _legacy_session as session
import logging
from argus_cli.plugin import register_command
from argus_plugins import argus_cli_module
from argus_api.utils import deprecated_alias
log = logging.getLogger(__name__)


@register_command(
    extending=("world", "v1", "whois"),
    module=argus_cli_module
)
def lookup_whois(
    lookup: str = None,
    json: bool = True,
    verify: bool = None,
    proxies: dict = None,
    apiKey: str = None,
    authentication: dict = {},
    server_url: str = None,
    body: dict = None,
) -> dict:
    """Get WHOIS information by IP or host name (PUBLIC)
    
    :param str lookup: Lookup WhoIs information for specified value
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises NotFoundException: on 404
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/world/v1/whois".format(lookup=lookup)
    headers = {}

    body = body or {}

    query_parameters = {}
    # Only send lookup if the argument was provided, don't send null values
    if lookup is not None:
        query_parameters.update({"lookup": lookup})
    
    log.debug("GET %s (headers: %s, body: %s)" % (route, str(headers), str(body) or ""))

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response

#: **DEPRECATED** : ``lookup_who_is`` is an alias for ``lookup_whois``. Exists
#: only for backward compatibility - **do not use** - use ``lookup_whois`` instead.
lookup_who_is = register_command(
    extending=("world", "v1", "whois"),
    module=argus_cli_module,
    alias="lookup_who_is"
)(deprecated_alias("lookup_who_is")(lookup_whois))