"""Autogenerated API"""
from argus_api.session import get_session
from typing import TYPE_CHECKING, Optional
if TYPE_CHECKING:
    from argus_api.session import ArgusAPISession


def get_asset_cpes(
    idOrWFN: str,
    json: bool = True,
    verify: Optional[bool] = None,
    proxies: Optional[dict] = None,
    apiKey: Optional[str] = None,
    authentication: Optional[dict] = None,
    server_url: Optional[str] = None,
    body: Optional[dict] = None,
    api_session: Optional["ArgusAPISession"] = None,
) -> dict:
    """Get CPE by ID or WFN (DEV)
    
    :param str idOrWFN: CPE ID or WFN
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :param api_session: session to use for this request. If not set, the global session will be used.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ObjectNotFoundException: on 404
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/assets/v2/cpe/{idOrWFN}".format(idOrWFN=idOrWFN)

    session = api_session or get_session()
    headers = {}

    body = body or {}

    query_parameters = {}

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response


def list_asset_cpes(
    keywords: str = None,
    vendor: str = None,
    product: str = None,
    version: str = None,
    sortBy: str = None,
    startTimestamp: str = "0",
    endTimestamp: str = "0",
    limit: int = 25,
    includeDeprecated: bool = None,
    offset: int = None,
    json: bool = True,
    verify: Optional[bool] = None,
    proxies: Optional[dict] = None,
    apiKey: Optional[str] = None,
    authentication: Optional[dict] = None,
    server_url: Optional[str] = None,
    body: Optional[dict] = None,
    api_session: Optional["ArgusAPISession"] = None,
) -> dict:
    """Basic CPE search. (DEV)
    
    :param list keywords: Match keywords against all available CPE keyword fields
    :param list vendor: CPE Vendor
    :param list product: CPE Product
    :param list version: CPE Version
    :param list sortBy: Field\(s\) to sort by \- refer to the search POST endpoint to see which fields are permitted
    :param str startTimestamp: Lower bound timestamp filter value against all available CPE timestamp fields
    :param str endTimestamp: Upper bound timestamp filter value against all available CPE timestamp fields
    :param int limit: Limit result set
    :param bool includeDeprecated: Whether to include deprecated CPEs in the results
    :param int offset: Offset result set
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :param api_session: session to use for this request. If not set, the global session will be used.
    :returns: dictionary translated from JSON
    """

    route = "/assets/v2/cpe".format(startTimestamp=startTimestamp,
        endTimestamp=endTimestamp,
        limit=limit,
        keywords=keywords,
        vendor=vendor,
        product=product,
        version=version,
        includeDeprecated=includeDeprecated,
        offset=offset,
        sortBy=sortBy)

    session = api_session or get_session()
    headers = {}

    body = body or {}

    query_parameters = {}
    # Only send startTimestamp if the argument was provided, don't send null values
    if startTimestamp is not None:
        query_parameters.update({"startTimestamp": startTimestamp})
    
    # Only send endTimestamp if the argument was provided, don't send null values
    if endTimestamp is not None:
        query_parameters.update({"endTimestamp": endTimestamp})
    
    # Only send limit if the argument was provided, don't send null values
    if limit is not None:
        query_parameters.update({"limit": limit})
    
    # Only send keywords if the argument was provided, don't send null values
    if keywords is not None:
        query_parameters.update({"keywords": keywords})
    
    # Only send vendor if the argument was provided, don't send null values
    if vendor is not None:
        query_parameters.update({"vendor": vendor})
    
    # Only send product if the argument was provided, don't send null values
    if product is not None:
        query_parameters.update({"product": product})
    
    # Only send version if the argument was provided, don't send null values
    if version is not None:
        query_parameters.update({"version": version})
    
    # Only send includeDeprecated if the argument was provided, don't send null values
    if includeDeprecated is not None:
        query_parameters.update({"includeDeprecated": includeDeprecated})
    
    # Only send offset if the argument was provided, don't send null values
    if offset is not None:
        query_parameters.update({"offset": offset})
    
    # Only send sortBy if the argument was provided, don't send null values
    if sortBy is not None:
        query_parameters.update({"sortBy": sortBy})
    

    response = session.get(
        route,
        params=query_parameters or None,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response


def search_cpes(
    keywords: str = None,
    keywordFieldStrategy: str = None,
    keywordMatchStrategy: str = None,
    cpe: str = None,
    part: str = None,
    vendor: str = None,
    product: str = None,
    version: str = None,
    startTimestamp: str = None,
    endTimestamp: str = None,
    timeFieldStrategy: str = None,
    timeMatchStrategy: str = None,
    deprecates: str = None,
    deprecatedBy: str = None,
    includeFlags: str = None,
    excludeFlags: str = None,
    subCriteria: dict = None,
    sortBy: str = None,
    limit: int = 25,
    offset: int = None,
    includeDeprecated: bool = None,
    json: bool = True,
    verify: Optional[bool] = None,
    proxies: Optional[dict] = None,
    apiKey: Optional[str] = None,
    authentication: Optional[dict] = None,
    server_url: Optional[str] = None,
    body: Optional[dict] = None,
    api_session: Optional["ArgusAPISession"] = None,
) -> dict:
    """Search CPEs (DEV)
    
    :param list keywords: Search for keywords against fields defined by a KeywordFieldStrategy
    :param list keywordFieldStrategy: Defines which fields will be searched by keywords \(default all supported fields\) \(default all\)
    :param str keywordMatchStrategy: Defines how strict different keywords should be matched \(default match any keywords\) \(default any\)
    :param list cpe: Filter for CPEs matching one of these WFN or ID values
    :param list part: Filter for CPEs matching one of these part values
    :param list vendor: Filter for CPEs matching one of these vendors values
    :param list product: Filter for CPEs matching one of these products values
    :param list version: Filter for CPEs matching one of these versions values
    :param str startTimestamp: Restrict to a time frame based on the set timeFieldStrategy \(start timestamp\). \(default 0\)
    :param str endTimestamp: Restrict to a time frame based on the set timeFieldStrategy \(end timestamp\). \(default 0\)
    :param list timeFieldStrategy: Defines which timestamps fields will be filtered with start\/endTimestamp \(default all\)
    :param str timeMatchStrategy: Defines how strict to match against different timestamps \(all\/any\) using start and end timestamp \(default any\) \(default any\)
    :param list deprecates: Filter for CPEs that deprecate at least one of these CPEs identified by ID or WFN
    :param list deprecatedBy: Filter for CPEs deprecated by at least one of these CPEs identified by ID or WFN
    :param list includeFlags: Explicitly search for CPEs that contain these flags
    :param list excludeFlags: Explicitly filter out CPEs that contain these flags
    :param list subCriteria: Set additional criteria that are applied with logical OR by default
    :param list sortBy: Field\(s\) by which to sort the results
    :param int limit: Limit the results to the specified amount \(default 25\)
    :param int offset: Skip specified amount of results \(default 0\)
    :param bool includeDeprecated: Whether to include deprecated CPEs \(default false\)
    :param json: return the response's body as a ``dict`` parsed from json. ``True`` by
      default. If set to false, the raw ``requests.Response`` object will be returned.
    :param verify: path to a certificate bundle or boolean indicating whether SSL
      verification should be performed.
    :param apiKey: Argus API key.
    :param authentication: authentication override
    :param server_url: API base URL override
    :param body: body of the request. other parameters will override keys defined in the body.
    :param api_session: session to use for this request. If not set, the global session will be used.
    :raises AuthenticationFailedException: on 401
    :raises AccessDeniedException: on 403
    :raises ValidationErrorException: on 412
    :raises ArgusException: on other status codes
    
    :returns: dictionary translated from JSON
    """

    route = "/assets/v2/cpe/search".format()

    session = api_session or get_session()
    headers = {}

    body = body or {}
    # Only send keywords if the argument was provided, don't send null values
    if keywords is not None:
        body.update({"keywords": keywords})
    # Only send keywordFieldStrategy if the argument was provided, don't send null values
    if keywordFieldStrategy is not None:
        body.update({"keywordFieldStrategy": keywordFieldStrategy})
    # Only send keywordMatchStrategy if the argument was provided, don't send null values
    if keywordMatchStrategy is not None:
        body.update({"keywordMatchStrategy": keywordMatchStrategy})
    # Only send cpe if the argument was provided, don't send null values
    if cpe is not None:
        body.update({"cpe": cpe})
    # Only send part if the argument was provided, don't send null values
    if part is not None:
        body.update({"part": part})
    # Only send vendor if the argument was provided, don't send null values
    if vendor is not None:
        body.update({"vendor": vendor})
    # Only send product if the argument was provided, don't send null values
    if product is not None:
        body.update({"product": product})
    # Only send version if the argument was provided, don't send null values
    if version is not None:
        body.update({"version": version})
    # Only send startTimestamp if the argument was provided, don't send null values
    if startTimestamp is not None:
        body.update({"startTimestamp": startTimestamp})
    # Only send endTimestamp if the argument was provided, don't send null values
    if endTimestamp is not None:
        body.update({"endTimestamp": endTimestamp})
    # Only send timeFieldStrategy if the argument was provided, don't send null values
    if timeFieldStrategy is not None:
        body.update({"timeFieldStrategy": timeFieldStrategy})
    # Only send timeMatchStrategy if the argument was provided, don't send null values
    if timeMatchStrategy is not None:
        body.update({"timeMatchStrategy": timeMatchStrategy})
    # Only send deprecates if the argument was provided, don't send null values
    if deprecates is not None:
        body.update({"deprecates": deprecates})
    # Only send deprecatedBy if the argument was provided, don't send null values
    if deprecatedBy is not None:
        body.update({"deprecatedBy": deprecatedBy})
    # Only send includeFlags if the argument was provided, don't send null values
    if includeFlags is not None:
        body.update({"includeFlags": includeFlags})
    # Only send excludeFlags if the argument was provided, don't send null values
    if excludeFlags is not None:
        body.update({"excludeFlags": excludeFlags})
    # Only send subCriteria if the argument was provided, don't send null values
    if subCriteria is not None:
        body.update({"subCriteria": subCriteria})
    # Only send limit if the argument was provided, don't send null values
    if limit is not None:
        body.update({"limit": limit})
    # Only send offset if the argument was provided, don't send null values
    if offset is not None:
        body.update({"offset": offset})
    # Only send sortBy if the argument was provided, don't send null values
    if sortBy is not None:
        body.update({"sortBy": sortBy})
    # Only send includeDeprecated if the argument was provided, don't send null values
    if includeDeprecated is not None:
        body.update({"includeDeprecated": includeDeprecated})

    query_parameters = {}

    response = session.post(
        route,
        params=query_parameters or None,
        json=body,
        verify=verify,
        apiKey=apiKey,
        authentication=authentication,
        server_url=server_url,
        headers=headers,
        proxies=proxies,
    )
    return response.json() if json else response
